MAYBE

The TRS could not be proven terminating. The proof attempt took 6187 ms.

The following DP Processors were used


Problem 1 was processed with processor PolynomialLinearRange4iUR (0ms).
 | – Problem 2 was processed with processor PolynomialLinearRange4iUR (0ms).
 |    | – Problem 3 remains open; application of the following processors failed [DependencyGraph (0ms), PolynomialLinearRange4iUR (85ms), DependencyGraph (2ms), PolynomialLinearRange8NegiUR (1820ms), DependencyGraph (4ms), ReductionPairSAT (3711ms), DependencyGraph (1ms), SizeChangePrinciple (4ms)].

The following open problems remain:



Open Dependency Pair Problem 3

Dependency Pairs

f#(f(a, x), a) → f#(f(x, f(a, f(a, a))), a)

Rewrite Rules

f(f(a, x), a) → f(f(x, f(a, f(a, a))), a)

Original Signature

Termination of terms over the following signature is verified: f, a


Problem 1: PolynomialLinearRange4iUR



Dependency Pair Problem

Dependency Pairs

f#(f(a, x), a) → f#(f(x, f(a, f(a, a))), a)f#(f(a, x), a) → f#(a, a)
f#(f(a, x), a) → f#(x, f(a, f(a, a)))f#(f(a, x), a) → f#(a, f(a, a))

Rewrite Rules

f(f(a, x), a) → f(f(x, f(a, f(a, a))), a)

Original Signature

Termination of terms over the following signature is verified: f, a

Strategy


Polynomial Interpretation

Improved Usable rules

f(f(a, x), a) → f(f(x, f(a, f(a, a))), a)

The following dependency pairs are strictly oriented by an ordering on the given polynomial interpretation, thus they are removed:

f#(f(a, x), a) → f#(a, f(a, a))f#(f(a, x), a) → f#(x, f(a, f(a, a)))

Problem 2: PolynomialLinearRange4iUR



Dependency Pair Problem

Dependency Pairs

f#(f(a, x), a) → f#(f(x, f(a, f(a, a))), a)f#(f(a, x), a) → f#(a, a)

Rewrite Rules

f(f(a, x), a) → f(f(x, f(a, f(a, a))), a)

Original Signature

Termination of terms over the following signature is verified: f, a

Strategy


Polynomial Interpretation

Improved Usable rules

f(f(a, x), a) → f(f(x, f(a, f(a, a))), a)

The following dependency pairs are strictly oriented by an ordering on the given polynomial interpretation, thus they are removed:

f#(f(a, x), a) → f#(a, a)